# SPDX-License-Identifier: Apache-2.0

from vllm import ModelRegistry


def register():
    from .mbart import MBartForConditionalGeneration

    # "BartModel": ("bart", "BartForConditionalGeneration"),
    # "BartForConditionalGeneration": ("bart", "BartForConditionalGeneration"),
    if "MBartModel" not in ModelRegistry.get_supported_archs():
        ModelRegistry.register_model("MBartModel", MBartForConditionalGeneration)

    if "MBartForConditionalGeneration" not in ModelRegistry.get_supported_archs():
        ModelRegistry.register_model("MBartForConditionalGeneration", MBartForConditionalGeneration)



# https://docs.vllm.ai/en/stable/contributing/model/registration.html
# https://docs.vllm.ai/en/stable/design/plugin_system.html

from setuptools import setup

setup(name='vllm_mbart',
      version='0.1',
      packages=['vllm_mbart'],
      install_requires=["vllm>=0.9.0"],
      entry_points={
          'vllm.general_plugins':
              ["register_mbart = vllm_mbart:register"]
      })
